==> healthrian_visualization_support-1.0.53.tar.gz: lib/src/widgets/cardio_click/control_panel_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelCardioClick extends StatelessWidget {
  const ControlPanelCardioClick({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#1',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#2',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            BLEManager().manageCardioClick.isFilteredEcg = false;
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#3',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#4',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#5',
          onPressed: () {
            BLEManager().setMode(enableList: [false, true, false]);
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}

==> healthrian_visualization_support-1.1.1.tar.gz: lib/src/widgets/cardio_click/control_panel_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'package:flutter/material.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

class ControlPanelCardioClick extends StatelessWidget {
  const ControlPanelCardioClick({super.key});

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#1',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            await BLEManager().connectDevice();
            await BLEManager().registerCharacteristics();
          },
          child: const Icon(Icons.bluetooth),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#2',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            // BLEManager().manageCardioClick.isFilteredEcg = false;
            await BLEManager().startMeasurement();
          },
          child: const Icon(Icons.play_arrow),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#3',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            await BLEManager().pauseMeasurement();
          },
          child: const Icon(Icons.pause),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#4',
          onPressed: () async {
            BLEManager().setMode(enableList: [false, true, false]);
            await BLEManager().stopMeasurement();
            await BLEManager().initializeStreams();
          },
          child: const Icon(Icons.stop),
        ),
        const SizedBox(height: 8),
        FloatingActionButton(
          heroTag: 'ControlPanelCardioClick#5',
          onPressed: () {
            BLEManager().setMode(enableList: [false, true, false]);
            BLEManager().disconnectDevice();
          },
          child: const Icon(Icons.bluetooth_disabled),
        ),
      ],
    );
  }
}
